@@ -26,6 +26,22 @@ class Plot:
     mdd = 0
     sharp = 0
 
+    save_path = 'save_path'
+    initial_capital = 0
+    net_profit_to_mdd = 0
+    net_profit = 0
+    mdd_dollar = 0
+    mdd_pct = 0
+    num_of_trade = 0
+    num_of_win = 0
+    return_on_capital = 0
+    sharp = 0
+    total_commission = 0
+    year_list = []
+    year_count = []
+    year_win_count = []
+
+
 
     def __new__(self, filename, output_folder, start_date, end_date, para_dict, result_df, generate_filepath, settings):
 
@@ -33,6 +49,10 @@ class Plot:
 
         components = Components()
 
+        start_date_year = datetime.datetime.strptime(start_date, '%Y-%m-%d').year
+        end_date_year = datetime.datetime.strptime(end_date, '%Y-%m-%d').year
+        self.year_list = list(range(start_date_year, end_date_year + 1))
+
         empty_line_chart = components.empty_line_chart()
         checkbox_div = components.update_checkbox_div(para_dict, result_df)
         col_df = result_df.columns.values.tolist()
@@ -116,7 +136,7 @@ class Plot:
                     # Middle Column
                     dbc.Col(html.Div([
 
-                        html.Div(id='performance_matrix', children=performance_matrix ),
+                        html.Div(id='performance_matrix', children=performance_matrix),
 
                     ], style={'padding': '5px',})
                         , style={'padding': '0', }, width=2),
@@ -284,16 +304,6 @@ class Plot:
                         filter_dropdown_div = filter_dropdown
                         filter_input_div = filter_input
 
-                   # if not chart1_button_click:
-                   #     print('No!!!')
-                   #     self.line_selected = -1
-                   # self.chart_type = 1
-                   # hist_area = []
-                   # hist_style = {'display': 'none'}
-                   # self.init = True
-                   # filter_dropdown_div = filter_dropdown
-                   # filter_input_div = filter_input
-
 
             ## Add Button Pressed
             if add_button_clicks:
@@ -422,10 +432,26 @@ class Plot:
                     df = self.graph_df.iloc[i].copy()
                     self.save_path = save_path
                     self.initial_capital = pd.read_csv(save_path).iloc[0].equity_value
-                    self.return_in_capital = df['return_on_capital']
-                    self.mdd = df['mdd_pct']
+                    self.net_profit_to_mdd = df['net_profit_to_mdd']
+                    self.net_profit = df['net_profit']
+                    self.mdd_dollar = df['mdd_dollar']
+                    self.mdd_pct = df['mdd_pct']
+                    self.num_of_trade = df['num_of_trade']
+                    self.num_of_win = round(int(df['num_of_trade'])*float(df['win_rate'])/100)
+                    self.return_on_capital = df['return_on_capital']
                     self.sharp = df['annualized_sr']
-
+                    self.total_commission = df['total_commission']
+                    year_count = []
+                    year_win_count = []
+                    for year in self.year_list:
+                        if not df[f'{year}_win_rate'] == '--':
+                            win_count = round(int(df[str(year)])*float(df[f'{year}_win_rate'])/100)
+                        else:
+                            win_count = 0
+                        year_count.append(df[str(year)])
+                        year_win_count.append(win_count)
+                    self.year_count = year_count
+                    self.year_win_count = year_win_count
 
             return performance_matrix, button_style
 
@@ -439,7 +465,14 @@ class Plot:
         )
         def save_button(save_clicks):
             if not os.path.isfile('saved_strategies.csv'):
-                pd.DataFrame(columns=['path','initial','return','mdd','sharp']).to_csv('saved_strategies.csv', index=False)
+                columns = ['path','initial','net_profit_to_mdd','net_profit',
+                                      'mdd_dollar','mdd_pct','num_of_trade','num_of_win',
+                                      'return_on_capital','total_commission','sharp'
+                                      ]
+                for year in self.year_list:
+                    columns.append(year)
+                    columns.append(f'{year}_win_count')
+                pd.DataFrame(columns=columns).to_csv('saved_strategies.csv', index=False)
             else:
                 pass
 
@@ -475,12 +508,23 @@ class Plot:
                             saved_df = pd.read_csv('saved_strategies.csv')
 
                             if not save_path in list(saved_df['path']):
-                                saved_df = pd.concat([saved_df, pd.DataFrame({'path': save_path,
-                                                                              'initial': self.initial_capital,
-                                                                              'return': self.return_in_capital,
-                                                                              'mdd': self.mdd,
-                                                                              'sharp': self.sharp,
-                                                                              },index=[10])],
+                                df_dict = {'path': save_path,
+                                           'initial': self.initial_capital,
+                                           'net_profit_to_mdd': self.net_profit_to_mdd,
+                                           'net_profit': self.net_profit,
+                                           'mdd_dollar':self.mdd_dollar,
+                                           'mdd_pct':self.mdd_pct,
+                                           'num_of_trade':self.num_of_trade,
+                                           'num_of_win': self.num_of_win,
+                                           'return_on_capital': self.return_on_capital,
+                                           'sharp': self.sharp,
+                                           'total_commission': self.total_commission,
+                                           }
+                                for i, year in enumerate(self.year_list):
+                                    df_dict[str(year)] = self.year_count[i]
+                                    df_dict[f'{year}_win_count'] = self.year_win_count[i]
+
+                                saved_df = pd.concat([saved_df, pd.DataFrame(df_dict,index=[10])],
                                                      ignore_index=True)
                                 button_available = False
                             else:
